emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] Changes to emacs/lisp/net/tramp-ftp.el,v


From: Michael Albinus
Subject: [Emacs-diffs] Changes to emacs/lisp/net/tramp-ftp.el,v
Date: Fri, 24 Aug 2007 05:27:23 +0000

CVSROOT:        /cvsroot/emacs
Module name:    emacs
Changes by:     Michael Albinus <albinus>       07/08/24 05:27:23

Index: net/tramp-ftp.el
===================================================================
RCS file: /cvsroot/emacs/emacs/lisp/net/tramp-ftp.el,v
retrieving revision 1.18
retrieving revision 1.19
diff -u -b -r1.18 -r1.19
--- net/tramp-ftp.el    29 Jul 2007 15:32:56 -0000      1.18
+++ net/tramp-ftp.el    24 Aug 2007 05:27:22 -0000      1.19
@@ -30,6 +30,7 @@
 ;;; Code:
 
 (require 'tramp)
+(autoload 'tramp-set-connection-property "tramp-cache")
 
 (eval-when-compile (require 'custom))
 
@@ -137,12 +138,18 @@
          (ange-ftp-ftp-name-arg "")
          (ange-ftp-ftp-name-res nil))
       (cond
        ;; If argument is a symlink, `file-directory-p' and `file-exists-p'
        ;; call the traversed file recursively. So we cannot disable the
        ;; file-name-handler this case.
        ((memq operation '(file-directory-p file-exists-p))
-       (apply 'ange-ftp-hook-function operation args))
-       ;; Normally, the handlers must be discarded
+       (if (apply 'ange-ftp-hook-function operation args)
+           (with-parsed-tramp-file-name (car args) nil
+             (tramp-set-connection-property v "started" t))
+         nil))
+       ;; Normally, the handlers must be discarded.
        (t (let* ((inhibit-file-name-handlers
                   (list 'tramp-file-name-handler
                         'tramp-completion-file-name-handler
@@ -137,12 +138,18 @@
          (ange-ftp-ftp-name-res nil))
       (cond
-       ;; If argument is a symlink, `file-directory-p' and `file-exists-p'
-       ;; call the traversed file recursively. So we cannot disable the
-       ;; file-name-handler this case.
+       ;; If argument is a symlink, `file-directory-p' and
+       ;; `file-exists-p' call the traversed file recursively. So we
+       ;; cannot disable the file-name-handler this case.  We set the
+       ;; connection property "started" in order to put the remote
+       ;; location into the cache, which is helpful for further
+       ;; completion.
        ((memq operation '(file-directory-p file-exists-p))




reply via email to

[Prev in Thread] Current Thread [Next in Thread]